# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.file_assets_with_includes_response import FileAssetsWithIncludesResponse
from ..types.file_copy_response import FileCopyResponse
from ..types.file_remote_upload_response import FileRemoteUploadResponse
from ..types.file_response import FileResponse
from ..types.file_upload_status_response import FileUploadStatusResponse
from ..types.file_with_includes_response import FileWithIncludesResponse
from ..types.file_with_upload_urls_response import FileWithUploadUrlsResponse
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawFilesClient, RawFilesClient
from .types.file_copy_params_data import FileCopyParamsData
from .types.file_create_local_upload_params_data import FileCreateLocalUploadParamsData
from .types.file_create_params_data import FileCreateParamsData
from .types.file_create_remote_upload_params_data import FileCreateRemoteUploadParamsData
from .types.file_move_params_data import FileMoveParamsData
from .types.file_update_params_data import FileUpdateParamsData
from .types.files_copy_request_copy_comments import FilesCopyRequestCopyComments
from .types.files_list_request_include import FilesListRequestInclude
from .types.files_list_request_sort import FilesListRequestSort
from .types.files_show_request_include import FilesShowRequestInclude

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FilesClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFilesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFilesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFilesClient
        """
        return self._raw_client

    def list(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FilesListRequestInclude] = None,
        sort: typing.Optional[FilesListRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileAssetsWithIncludesResponse:
        """
        List files in a given folder. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FilesListRequestInclude]


        sort : typing.Optional[FilesListRequestSort]
            Sort files by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileAssetsWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.list(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include="media_links",
            sort="name_asc",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.list(
            account_id,
            folder_id,
            include=include,
            sort=sort,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithUploadUrlsResponse:
        """
        Create new file under parent folder. `Create file (local upload)` and `Create file (remote upload)` have replaced this endpoint. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithUploadUrlsResponse
            Created

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileCreateParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FileCreateParamsData(
                file_size=1137444,
                media_type="image/png",
                name="asset.png",
            ),
        )
        """
        _response = self._raw_client.create(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    def show(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        include: typing.Optional[FilesShowRequestInclude] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithIncludesResponse:
        """
        Show file details.
        <br>
        Use the `include` query parameter to selectively include additional properties in the response.
        <br>
        Note: if you include `media_links.original` and the user does not have permission to download the file
        then this endpoint will respond with a `403 Forbidden` error. If the content is inaccessible because
        watermarking is required for this user and isn't supported by the requested media_links, then the request will
        succeed but the unsupported media links will be set to null.
        Similarly, if a requested transcode link does not exist for a particular file (e.g. including
        `media_links.video_h264_180` on a static image file) or transoding process hasn't completed
        (i.e. the file's `status` is "uploaded" rather than "transcoded"), then the link will also be set to null in
        the response payload. In short, the client must handle null media links gracefully.
        <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        include : typing.Optional[FilesShowRequestInclude]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include="media_links",
        )
        """
        _response = self._raw_client.show(account_id, file_id, include=include, request_options=request_options)
        return _response.data

    def delete(
        self, account_id: Uuid, file_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete file by ID. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.delete(account_id, file_id, request_options=request_options)
        return _response.data

    def update(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        data: FileUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileResponse:
        """
        Update file details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        data : FileUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileUpdateParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FileUpdateParamsData(
                name="asset.png",
            ),
        )
        """
        _response = self._raw_client.update(account_id, file_id, data=data, request_options=request_options)
        return _response.data

    def copy(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        copy_metadata: typing.Optional[bool] = None,
        copy_comments: typing.Optional[FilesCopyRequestCopyComments] = None,
        data: typing.Optional[FileCopyParamsData] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileCopyResponse:
        """
        Copy file. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        copy_metadata : typing.Optional[bool]
            Whether to copy metadata values along with the file

        copy_comments : typing.Optional[FilesCopyRequestCopyComments]
            Which comments to copy along with the file

        data : typing.Optional[FileCopyParamsData]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileCopyResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileCopyParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.copy(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            copy_metadata=True,
            copy_comments="none",
            data=FileCopyParamsData(
                parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
            ),
        )
        """
        _response = self._raw_client.copy(
            account_id,
            file_id,
            copy_metadata=copy_metadata,
            copy_comments=copy_comments,
            data=data,
            request_options=request_options,
        )
        return _response.data

    def create_remote_upload(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateRemoteUploadParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileRemoteUploadResponse:
        """
        Create new file under parent folder through remote upload. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateRemoteUploadParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileRemoteUploadResponse
            Accepted

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileCreateRemoteUploadParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.create_remote_upload(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FileCreateRemoteUploadParamsData(
                name="asset.png",
                source_url="https://upload.wikimedia.org/wikipedia/commons/e/e1/White_Pixel_1x1.png",
            ),
        )
        """
        _response = self._raw_client.create_remote_upload(
            account_id, folder_id, data=data, request_options=request_options
        )
        return _response.data

    def move(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        data: FileMoveParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileResponse:
        """
        Move file to a folder or version_stack. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        data : FileMoveParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileMoveParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.move(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FileMoveParamsData(
                parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
            ),
        )
        """
        _response = self._raw_client.move(account_id, file_id, data=data, request_options=request_options)
        return _response.data

    def create_local_upload(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateLocalUploadParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithUploadUrlsResponse:
        """
        Create new file under parent folder through local upload. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateLocalUploadParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithUploadUrlsResponse
            Created

        Examples
        --------
        from frameio import Frameio
        from frameio.files import FileCreateLocalUploadParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.create_local_upload(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FileCreateLocalUploadParamsData(
                file_size=1137444,
                name="asset.png",
            ),
        )
        """
        _response = self._raw_client.create_local_upload(
            account_id, folder_id, data=data, request_options=request_options
        )
        return _response.data

    def show_file_upload_status(
        self, account_id: Uuid, file_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> FileUploadStatusResponse:
        """
        Show file upload status details. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileUploadStatusResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.files.show_file_upload_status(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.show_file_upload_status(account_id, file_id, request_options=request_options)
        return _response.data


class AsyncFilesClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFilesClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFilesClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFilesClient
        """
        return self._raw_client

    async def list(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FilesListRequestInclude] = None,
        sort: typing.Optional[FilesListRequestSort] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileAssetsWithIncludesResponse:
        """
        List files in a given folder. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FilesListRequestInclude]


        sort : typing.Optional[FilesListRequestSort]
            Sort files by query params

        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileAssetsWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.list(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include="media_links",
                sort="name_asc",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            account_id,
            folder_id,
            include=include,
            sort=sort,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithUploadUrlsResponse:
        """
        Create new file under parent folder. `Create file (local upload)` and `Create file (remote upload)` have replaced this endpoint. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithUploadUrlsResponse
            Created

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileCreateParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FileCreateParamsData(
                    file_size=1137444,
                    media_type="image/png",
                    name="asset.png",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    async def show(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        include: typing.Optional[FilesShowRequestInclude] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithIncludesResponse:
        """
        Show file details.
        <br>
        Use the `include` query parameter to selectively include additional properties in the response.
        <br>
        Note: if you include `media_links.original` and the user does not have permission to download the file
        then this endpoint will respond with a `403 Forbidden` error. If the content is inaccessible because
        watermarking is required for this user and isn't supported by the requested media_links, then the request will
        succeed but the unsupported media links will be set to null.
        Similarly, if a requested transcode link does not exist for a particular file (e.g. including
        `media_links.video_h264_180` on a static image file) or transoding process hasn't completed
        (i.e. the file's `status` is "uploaded" rather than "transcoded"), then the link will also be set to null in
        the response payload. In short, the client must handle null media links gracefully.
        <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        include : typing.Optional[FilesShowRequestInclude]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include="media_links",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show(account_id, file_id, include=include, request_options=request_options)
        return _response.data

    async def delete(
        self, account_id: Uuid, file_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete file by ID. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(account_id, file_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        data: FileUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileResponse:
        """
        Update file details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        data : FileUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileUpdateParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FileUpdateParamsData(
                    name="asset.png",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(account_id, file_id, data=data, request_options=request_options)
        return _response.data

    async def copy(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        copy_metadata: typing.Optional[bool] = None,
        copy_comments: typing.Optional[FilesCopyRequestCopyComments] = None,
        data: typing.Optional[FileCopyParamsData] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileCopyResponse:
        """
        Copy file. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        copy_metadata : typing.Optional[bool]
            Whether to copy metadata values along with the file

        copy_comments : typing.Optional[FilesCopyRequestCopyComments]
            Which comments to copy along with the file

        data : typing.Optional[FileCopyParamsData]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileCopyResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileCopyParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.copy(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                copy_metadata=True,
                copy_comments="none",
                data=FileCopyParamsData(
                    parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.copy(
            account_id,
            file_id,
            copy_metadata=copy_metadata,
            copy_comments=copy_comments,
            data=data,
            request_options=request_options,
        )
        return _response.data

    async def create_remote_upload(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateRemoteUploadParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileRemoteUploadResponse:
        """
        Create new file under parent folder through remote upload. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateRemoteUploadParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileRemoteUploadResponse
            Accepted

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileCreateRemoteUploadParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.create_remote_upload(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FileCreateRemoteUploadParamsData(
                    name="asset.png",
                    source_url="https://upload.wikimedia.org/wikipedia/commons/e/e1/White_Pixel_1x1.png",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_remote_upload(
            account_id, folder_id, data=data, request_options=request_options
        )
        return _response.data

    async def move(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        data: FileMoveParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileResponse:
        """
        Move file to a folder or version_stack. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        data : FileMoveParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileMoveParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.move(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FileMoveParamsData(
                    parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.move(account_id, file_id, data=data, request_options=request_options)
        return _response.data

    async def create_local_upload(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FileCreateLocalUploadParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FileWithUploadUrlsResponse:
        """
        Create new file under parent folder through local upload. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FileCreateLocalUploadParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileWithUploadUrlsResponse
            Created

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.files import FileCreateLocalUploadParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.create_local_upload(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FileCreateLocalUploadParamsData(
                    file_size=1137444,
                    name="asset.png",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create_local_upload(
            account_id, folder_id, data=data, request_options=request_options
        )
        return _response.data

    async def show_file_upload_status(
        self, account_id: Uuid, file_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> FileUploadStatusResponse:
        """
        Show file upload status details. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FileUploadStatusResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.files.show_file_upload_status(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                file_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show_file_upload_status(account_id, file_id, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .webhook_events import WebhookEvents


class Webhook(UncheckedBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Webhook active status
    """

    created_at: dt.datetime
    events: WebhookEvents
    id: str = pydantic.Field()
    """
    Webhook ID
    """

    name: str = pydantic.Field()
    """
    Webhook Name
    """

    updated_at: dt.datetime
    url: str
    workspace_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Workspace ID
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class VersionStackCreateParamsData(UncheckedBaseModel):
    file_ids: typing.List[str] = pydantic.Field()
    """
    An array of file IDs in the Version Stack.
    <br/>
    The Version Stack will be created by "stacking" the `file_ids` argument in order from left (oldest/bottom version in the stack) to right (newest/top version in the stack).
    <br/>
    Two file IDs are required and up to a maximum of ten. Files must exist in the parent directory identified in the path.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.account import Account
from ..types.accounts_response import AccountsResponse
from ..types.audit_logs_with_includes_response import AuditLogsWithIncludesResponse
from ..types.filters import Filters
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawAccountsClient, RawAccountsClient


class AccountsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawAccountsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawAccountsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawAccountsClient
        """
        return self._raw_client

    def index(
        self,
        *,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[Account, AccountsResponse]:
        """
        List accounts for the current user. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[Account, AccountsResponse]
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        response = client.accounts.index(
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.index(
            after=after, page_size=page_size, include_total_count=include_total_count, request_options=request_options
        )

    def auditlog_index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["user"]] = None,
        filters: typing.Optional[Filters] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AuditLogsWithIncludesResponse:
        """
        List audit logs with filtering capabilities via query params. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["user"]]


        filters : typing.Optional[Filters]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AuditLogsWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.accounts.auditlog_index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.auditlog_index(
            account_id,
            include=include,
            filters=filters,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data


class AsyncAccountsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawAccountsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawAccountsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawAccountsClient
        """
        return self._raw_client

    async def index(
        self,
        *,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[Account, AccountsResponse]:
        """
        List accounts for the current user. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[Account, AccountsResponse]
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = await client.accounts.index(
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.index(
            after=after, page_size=page_size, include_total_count=include_total_count, request_options=request_options
        )

    async def auditlog_index(
        self,
        account_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["user"]] = None,
        filters: typing.Optional[Filters] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AuditLogsWithIncludesResponse:
        """
        List audit logs with filtering capabilities via query params. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        include : typing.Optional[typing.Literal["user"]]


        filters : typing.Optional[Filters]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AuditLogsWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.accounts.auditlog_index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.auditlog_index(
            account_id,
            include=include,
            filters=filters,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .user_multi_definition_field_configuration_custom_members_item import (
    UserMultiDefinitionFieldConfigurationCustomMembersItem,
)
from .user_multi_definition_field_configuration_member_options_type import (
    UserMultiDefinitionFieldConfigurationMemberOptionsType,
)


class UserMultiDefinitionFieldConfiguration(UncheckedBaseModel):
    custom_members: typing.List[UserMultiDefinitionFieldConfigurationCustomMembersItem]
    member_options_type: UserMultiDefinitionFieldConfigurationMemberOptionsType
    notify_members: bool = pydantic.Field()
    """
    
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

from typing import Dict, Generic, TypeVar

import httpx

# Generic to represent the underlying type of the data wrapped by the HTTP response.
T = TypeVar("T")


class BaseHttpResponse:
    """Minimalist HTTP response wrapper that exposes response headers and status code."""

    _response: httpx.Response

    def __init__(self, response: httpx.Response):
        self._response = response

    @property
    def headers(self) -> Dict[str, str]:
        return dict(self._response.headers)

    @property
    def status_code(self) -> int:
        return self._response.status_code


class HttpResponse(Generic[T], BaseHttpResponse):
    """HTTP response wrapper that exposes response headers and data."""

    _data: T

    def __init__(self, response: httpx.Response, data: T):
        super().__init__(response)
        self._data = data

    @property
    def data(self) -> T:
        return self._data

    def close(self) -> None:
        self._response.close()


class AsyncHttpResponse(Generic[T], BaseHttpResponse):
    """HTTP response wrapper that exposes response headers and data."""

    _data: T

    def __init__(self, response: httpx.Response, data: T):
        super().__init__(response)
        self._data = data

    @property
    def data(self) -> T:
        return self._data

    async def close(self) -> None:
        await self._response.aclose()



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .links import Links
from .user_role import UserRole


class WorkspaceUserRolesResponse(UncheckedBaseModel):
    """
    Frame.io user role details
    """

    data: typing.List[UserRole] = pydantic.Field()
    """
    User Roles
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .account_user_role_role import AccountUserRoleRole
from .user import User


class AccountUserRole(UncheckedBaseModel):
    """
    Frame.io Account User Role
    """

    role: typing.Optional[AccountUserRoleRole] = pydantic.Field(default=None)
    """
    Account User Role
    """

    user: User

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .media_link_common import MediaLinkCommon


class RenditionMediaLink(MediaLinkCommon):
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL to transcoded media that won't include any Content-Disposition header in the response.<br>
    Watermarks may be applied as per Account settings and User permissions.<br>
    Media content may be streamed (e.g. when watermarks are required). Clients may issue a
    HEAD request to determine whether Content-Length and/or Accept-Ranges headers are present in order
    to determine whether the content can be downloaded in parallel chunks.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_user_single_definition_params_field_configuration_custom_members_item_type import (
    UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType,
)


class UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItem(UncheckedBaseModel):
    id: str = pydantic.Field()
    """
    User Id
    """

    type: UpdateUserSingleDefinitionParamsFieldConfigurationCustomMembersItemType

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from .project import Project
from .user import User


class ProjectWithIncludes(Project):
    description: typing.Optional[str] = pydantic.Field(default=None)
    """
    Project Description
    """

    owner: typing.Optional[User] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

FiltersEventType = typing.Union[
    typing.Literal[
        "access_request_approved",
        "access_request_denied",
        "access_request_submitted",
        "account_aup_migration_created",
        "account_aup_migration_deleted",
        "account_aup_migration_downgrade_completed",
        "account_aup_migration_downgrade_failed",
        "account_aup_migration_downgrade_requested",
        "account_aup_migration_product_migrated",
        "account_aup_migration_started",
        "account_aup_migration_updated",
        "account_aup_user_migration_completed",
        "account_aup_user_migration_created",
        "account_aup_user_migration_deleted",
        "account_aup_user_migration_failed",
        "account_aup_user_migration_on_hold",
        "account_aup_user_migration_started",
        "account_aup_user_migration_unheld",
        "account_aup_user_migration_updated",
        "account_delinquent",
        "account_field_created",
        "account_field_deleted",
        "account_field_updated",
        "account_fio_version_migrated",
        "account_locked",
        "account_member_created",
        "account_member_deleted",
        "account_member_updated",
        "account_mfa_enforced",
        "account_ownership_transferred",
        "account_permissions_granted_to_user",
        "account_restored",
        "account_updated",
        "account_user_deleted",
        "account_user_group_created",
        "account_user_group_deleted",
        "account_user_group_members_added",
        "account_user_group_members_removed",
        "account_user_group_updated",
        "account_user_updated",
        "action_created",
        "action_deleted",
        "action_updated",
        "admin_update_to_v4",
        "allowed_domain_created",
        "allowed_domain_deleted",
        "anonymous_user_created",
        "asset_assignee_changed",
        "asset_copied",
        "asset_created",
        "asset_deleted",
        "asset_metadata_created",
        "asset_moved",
        "asset_restored",
        "asset_status_changed",
        "asset_updated",
        "asset_versioned",
        "assets_unversioned",
        "bulk_account_deletion_started",
        "bulk_assets_deleted",
        "bulk_assets_restored",
        "bulk_assets_retranscoded",
        "bulk_emails_updated",
        "bulk_projects_activated",
        "bulk_projects_deactivated",
        "bulk_users_removed",
        "collaborator_added",
        "collaborator_deleted",
        "collection_updated",
        "comment_completed",
        "comment_created",
        "comment_deleted",
        "comment_liked",
        "comment_uncompleted",
        "comment_updated",
        "email_address_changed",
        "email_change_confirmation_requested",
        "email_confirmed",
        "file_uploaded",
        "google_auth_disabled",
        "google_auth_enabled",
        "high_risk_sign_up",
        "join_presentation_request_approved",
        "join_project_request_approved",
        "join_request_accepted",
        "join_request_created",
        "join_request_declined",
        "join_request_deleted",
        "join_request_reset",
        "join_review_link_request_approved",
        "join_team_request_approved",
        "label_updated",
        "login_factor_created",
        "login_factor_validated",
        "media_created",
        "media_deleted",
        "metadata_value_updated",
        "new_device_login",
        "new_user_email_confirmation_requested",
        "oauth_app_created",
        "oauth_app_deleted",
        "oauth_app_disabled",
        "oauth_app_enabled",
        "oauth_app_updated",
        "password_changed",
        "password_reset_requested",
        "pending_account_member_created",
        "pending_account_member_deleted",
        "pending_collaborator_created",
        "pending_collaborator_deleted",
        "pending_reviewer_created",
        "pending_reviewer_deleted",
        "pending_team_member_created",
        "pending_team_member_deleted",
        "plan_created",
        "plan_deleted",
        "plan_updated",
        "preference_updated",
        "presentation_created",
        "presentation_deleted",
        "presentation_updated",
        "project_activated",
        "project_archive_completed",
        "project_archived",
        "project_created",
        "project_deactivated",
        "project_deleted",
        "project_field_created",
        "project_field_deleted",
        "project_field_updated",
        "project_invite_link_created",
        "project_invite_link_revoked",
        "project_moved",
        "project_permissions_granted_to_account_user_group",
        "project_permissions_granted_to_user",
        "project_restored",
        "project_unarchive_completed",
        "project_unarchived",
        "project_updated",
        "push_tokens_added",
        "push_tokens_deleted",
        "resource_control_policies_updated",
        "resource_invite_sent",
        "review_link_assets_added",
        "review_link_assets_deleted",
        "review_link_created",
        "review_link_deleted",
        "review_link_emailed",
        "review_link_updated",
        "reviewer_created",
        "reviewer_deleted",
        "role_added",
        "role_removed",
        "sbwm_template_created",
        "sbwm_template_deleted",
        "sbwm_template_updated",
        "session_refreshed",
        "session_revoked",
        "share_activity_tracking_consent_changed",
        "share_branding_preset_updated",
        "share_created",
        "share_deleted",
        "share_invites_sent",
        "share_reviewers_added",
        "share_reviewers_removed",
        "share_updated",
        "share_viewed",
        "subscription_cancelled",
        "subscription_card_updated",
        "subscription_created",
        "subscription_line_item_created",
        "subscription_line_item_deleted",
        "subscription_restored",
        "subscription_updated",
        "team_created",
        "team_creator_updated",
        "team_deleted",
        "team_lifecycle_policy_updated",
        "team_member_created",
        "team_member_deleted",
        "team_member_reset",
        "team_member_updated",
        "team_updated",
        "transcript_completed_self",
        "transcript_diarization_consent_changed",
        "transfer_batch_completed",
        "user_anonymized",
        "user_deactivated",
        "user_login",
        "user_login_attempt",
        "user_logout",
        "user_mfa_enforced",
        "user_reactivated",
        "user_signup",
        "user_token_created",
        "user_token_deleted",
        "user_token_disabled",
        "user_token_enabled",
        "user_token_updated",
        "user_updated",
        "v4_planned_migration_creation_failed",
        "webhook_created",
        "webhook_deleted",
        "webhook_updated",
        "workfront_asset_approval_status_updated",
        "workspace_permissions_granted_to_account_user_group",
        "workspace_permissions_granted_to_user",
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

UserSingleDefinitionFieldConfigurationMemberOptionsType = typing.Union[
    typing.Literal["all_project_members", "custom"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.request_options import RequestOptions
from ..types.children_type import ChildrenType
from ..types.folder_assets_with_includes_response import FolderAssetsWithIncludesResponse
from ..types.folder_copy_response import FolderCopyResponse
from ..types.folder_response import FolderResponse
from ..types.folder_with_includes_response import FolderWithIncludesResponse
from ..types.folders_with_includes_response import FoldersWithIncludesResponse
from ..types.include_total_count import IncludeTotalCount
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawFoldersClient, RawFoldersClient
from .types.folder_copy_params_data import FolderCopyParamsData
from .types.folder_create_params_data import FolderCreateParamsData
from .types.folder_move_params_data import FolderMoveParamsData
from .types.folder_update_params_data import FolderUpdateParamsData
from .types.folders_index_request_include import FoldersIndexRequestInclude
from .types.folders_list_request_include import FoldersListRequestInclude
from .types.folders_show_request_include import FoldersShowRequestInclude

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class FoldersClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawFoldersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawFoldersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawFoldersClient
        """
        return self._raw_client

    def show(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersShowRequestInclude] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderWithIncludesResponse:
        """
        Show folder details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersShowRequestInclude]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include="creator",
        )
        """
        _response = self._raw_client.show(account_id, folder_id, include=include, request_options=request_options)
        return _response.data

    def delete(
        self, account_id: Uuid, folder_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete folder by id. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.delete(account_id, folder_id, request_options=request_options)
        return _response.data

    def update(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Update folder details. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.folders import FolderUpdateParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FolderUpdateParamsData(
                name="Folder name",
            ),
        )
        """
        _response = self._raw_client.update(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    def index(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersIndexRequestInclude] = None,
        type: typing.Optional[ChildrenType] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderAssetsWithIncludesResponse:
        """
        List the children in the given folder.
        <br>
        Use the `include` query parameter to selectively include additional properties in the response.
        <br>
        Note: if you include `media_links.original` and the user does not have permission to download files
        in the corresponding project, then this endpoint will respond with a `403 Forbidden` error.
        If the content is inaccessible because watermarking is required for this user and isn't supported by
        the requested media_links, then the request will succeed but the unsupported media links will be set to null.
        Similarly, if a requested transcode link does not exist for a particular file (e.g. including
        `media_links.video_h264_180` on a static image file) or transoding process hasn't finished
        (i.e. the file's `status` is "uploaded" rather than "transcoded"), then the a media link will also be set to
        null in the response payload. In short, the client must handle null media links gracefully.
        <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersIndexRequestInclude]


        type : typing.Optional[ChildrenType]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderAssetsWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include="media_links",
            type="file,folder,version_stack",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.index(
            account_id,
            folder_id,
            include=include,
            type=type,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def copy(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        copy_metadata: typing.Optional[bool] = None,
        data: typing.Optional[FolderCopyParamsData] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderCopyResponse:
        """
        Copy folder. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        copy_metadata : typing.Optional[bool]
            Whether to copy metadata values along with the folder

        data : typing.Optional[FolderCopyParamsData]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderCopyResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.folders import FolderCopyParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.copy(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            copy_metadata=True,
            data=FolderCopyParamsData(
                parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
            ),
        )
        """
        _response = self._raw_client.copy(
            account_id, folder_id, copy_metadata=copy_metadata, data=data, request_options=request_options
        )
        return _response.data

    def list(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersListRequestInclude] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FoldersWithIncludesResponse:
        """
        List folders in a given folder. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersListRequestInclude]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FoldersWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.list(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            include="creator",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        """
        _response = self._raw_client.list(
            account_id,
            folder_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    def create(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Create a new folder inside the given <i>folder_id</i> path param. <br>Rate Limits: 3 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            Created

        Examples
        --------
        from frameio import Frameio
        from frameio.folders import FolderCreateParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FolderCreateParamsData(
                name="Folder name",
            ),
        )
        """
        _response = self._raw_client.create(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    def move(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderMoveParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Move folder to a folder. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderMoveParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.folders import FolderMoveParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.folders.move(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=FolderMoveParamsData(
                parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
            ),
        )
        """
        _response = self._raw_client.move(account_id, folder_id, data=data, request_options=request_options)
        return _response.data


class AsyncFoldersClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawFoldersClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawFoldersClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawFoldersClient
        """
        return self._raw_client

    async def show(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersShowRequestInclude] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderWithIncludesResponse:
        """
        Show folder details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersShowRequestInclude]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include="creator",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show(account_id, folder_id, include=include, request_options=request_options)
        return _response.data

    async def delete(
        self, account_id: Uuid, folder_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete folder by id. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(account_id, folder_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Update folder details. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.folders import FolderUpdateParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FolderUpdateParamsData(
                    name="Folder name",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    async def index(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersIndexRequestInclude] = None,
        type: typing.Optional[ChildrenType] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderAssetsWithIncludesResponse:
        """
        List the children in the given folder.
        <br>
        Use the `include` query parameter to selectively include additional properties in the response.
        <br>
        Note: if you include `media_links.original` and the user does not have permission to download files
        in the corresponding project, then this endpoint will respond with a `403 Forbidden` error.
        If the content is inaccessible because watermarking is required for this user and isn't supported by
        the requested media_links, then the request will succeed but the unsupported media links will be set to null.
        Similarly, if a requested transcode link does not exist for a particular file (e.g. including
        `media_links.video_h264_180` on a static image file) or transoding process hasn't finished
        (i.e. the file's `status` is "uploaded" rather than "transcoded"), then the a media link will also be set to
        null in the response payload. In short, the client must handle null media links gracefully.
        <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersIndexRequestInclude]


        type : typing.Optional[ChildrenType]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderAssetsWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include="media_links",
                type="file,folder,version_stack",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.index(
            account_id,
            folder_id,
            include=include,
            type=type,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def copy(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        copy_metadata: typing.Optional[bool] = None,
        data: typing.Optional[FolderCopyParamsData] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderCopyResponse:
        """
        Copy folder. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        copy_metadata : typing.Optional[bool]
            Whether to copy metadata values along with the folder

        data : typing.Optional[FolderCopyParamsData]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderCopyResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.folders import FolderCopyParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.copy(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                copy_metadata=True,
                data=FolderCopyParamsData(
                    parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.copy(
            account_id, folder_id, copy_metadata=copy_metadata, data=data, request_options=request_options
        )
        return _response.data

    async def list(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        include: typing.Optional[FoldersListRequestInclude] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FoldersWithIncludesResponse:
        """
        List folders in a given folder. <br>Rate Limits: 5 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        include : typing.Optional[FoldersListRequestInclude]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FoldersWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.list(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                include="creator",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.list(
            account_id,
            folder_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )
        return _response.data

    async def create(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderCreateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Create a new folder inside the given <i>folder_id</i> path param. <br>Rate Limits: 3 calls per 1 second(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderCreateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            Created

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.folders import FolderCreateParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FolderCreateParamsData(
                    name="Folder name",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(account_id, folder_id, data=data, request_options=request_options)
        return _response.data

    async def move(
        self,
        account_id: Uuid,
        folder_id: Uuid,
        *,
        data: FolderMoveParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> FolderResponse:
        """
        Move folder to a folder. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        folder_id : Uuid


        data : FolderMoveParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        FolderResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.folders import FolderMoveParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.folders.move(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                folder_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=FolderMoveParamsData(
                    parent_id="2e426fe0-f965-4594-8b2b-b4dff1dc00ec",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.move(account_id, folder_id, data=data, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

import typing
from json.decoder import JSONDecodeError

from ..core.api_error import ApiError
from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.http_response import AsyncHttpResponse, HttpResponse
from ..core.jsonable_encoder import jsonable_encoder
from ..core.request_options import RequestOptions
from ..core.serialization import convert_and_respect_annotation_metadata
from ..core.unchecked_base_model import construct_type
from ..errors.bad_request_error import BadRequestError
from ..errors.conflict_error import ConflictError
from ..errors.forbidden_error import ForbiddenError
from ..errors.not_found_error import NotFoundError
from ..errors.too_many_requests_error import TooManyRequestsError
from ..errors.unauthorized_error import UnauthorizedError
from ..errors.unprocessable_entity_error import UnprocessableEntityError
from ..types.bad_request import BadRequest
from ..types.conflict import Conflict
from ..types.forbidden import Forbidden
from ..types.metadata_response import MetadataResponse
from ..types.not_found import NotFound
from ..types.too_many_requests import TooManyRequests
from ..types.unauthorized import Unauthorized
from ..types.uuid_ import Uuid
from .types.bulk_update_metadata_params_data import BulkUpdateMetadataParamsData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class RawMetadataClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._client_wrapper = client_wrapper

    def bulk_update(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        data: BulkUpdateMetadataParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[None]:
        """
        Update metadata values across multiple files. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        data : BulkUpdateMetadataParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[None]
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/projects/{jsonable_encoder(project_id)}/metadata/values",
            method="PATCH",
            json={
                "data": convert_and_respect_annotation_metadata(
                    object_=data, annotation=BulkUpdateMetadataParamsData, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return HttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    def show(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        show_null: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> HttpResponse[MetadataResponse]:
        """
        Show the metadata of a file. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        show_null : typing.Optional[bool]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HttpResponse[MetadataResponse]
            OK
        """
        _response = self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/files/{jsonable_encoder(file_id)}/metadata",
            method="GET",
            params={
                "show_null": show_null,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    MetadataResponse,
                    construct_type(
                        type_=MetadataResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return HttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)


class AsyncRawMetadataClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._client_wrapper = client_wrapper

    async def bulk_update(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        data: BulkUpdateMetadataParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[None]:
        """
        Update metadata values across multiple files. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        data : BulkUpdateMetadataParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[None]
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/projects/{jsonable_encoder(project_id)}/metadata/values",
            method="PATCH",
            json={
                "data": convert_and_respect_annotation_metadata(
                    object_=data, annotation=BulkUpdateMetadataParamsData, direction="write"
                ),
            },
            headers={
                "content-type": "application/json",
            },
            request_options=request_options,
            omit=OMIT,
        )
        try:
            if 200 <= _response.status_code < 300:
                return AsyncHttpResponse(response=_response, data=None)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)

    async def show(
        self,
        account_id: Uuid,
        file_id: Uuid,
        *,
        show_null: typing.Optional[bool] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncHttpResponse[MetadataResponse]:
        """
        Show the metadata of a file. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        file_id : Uuid


        show_null : typing.Optional[bool]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncHttpResponse[MetadataResponse]
            OK
        """
        _response = await self._client_wrapper.httpx_client.request(
            f"v4/accounts/{jsonable_encoder(account_id)}/files/{jsonable_encoder(file_id)}/metadata",
            method="GET",
            params={
                "show_null": show_null,
            },
            request_options=request_options,
        )
        try:
            if 200 <= _response.status_code < 300:
                _data = typing.cast(
                    MetadataResponse,
                    construct_type(
                        type_=MetadataResponse,  # type: ignore
                        object_=_response.json(),
                    ),
                )
                return AsyncHttpResponse(response=_response, data=_data)
            if _response.status_code == 400:
                raise BadRequestError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        BadRequest,
                        construct_type(
                            type_=BadRequest,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 401:
                raise UnauthorizedError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Unauthorized,
                        construct_type(
                            type_=Unauthorized,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 403:
                raise ForbiddenError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Forbidden,
                        construct_type(
                            type_=Forbidden,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 404:
                raise NotFoundError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        NotFound,
                        construct_type(
                            type_=NotFound,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 409:
                raise ConflictError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        Conflict,
                        construct_type(
                            type_=Conflict,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 422:
                raise UnprocessableEntityError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        typing.Any,
                        construct_type(
                            type_=typing.Any,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            if _response.status_code == 429:
                raise TooManyRequestsError(
                    headers=dict(_response.headers),
                    body=typing.cast(
                        TooManyRequests,
                        construct_type(
                            type_=TooManyRequests,  # type: ignore
                            object_=_response.json(),
                        ),
                    ),
                )
            _response_json = _response.json()
        except JSONDecodeError:
            raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response.text)
        raise ApiError(status_code=_response.status_code, headers=dict(_response.headers), body=_response_json)



# This file was auto-generated by Fern from our API Definition.

import typing

DateDefinitionFieldConfigurationTimeFormat = typing.Union[typing.Literal["twelve_hour", "twenty_four_hour"], typing.Any]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .links import Links
from .workspace_with_includes import WorkspaceWithIncludes


class WorkspacesWithIncludesResponse(UncheckedBaseModel):
    """
    Frame.io workspace details
    """

    data: typing.List[WorkspaceWithIncludes] = pydantic.Field()
    """
    Workspaces
    """

    links: Links
    total_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    Total count
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .update_select_multi_definition_params_field_configuration_options_item import (
    UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem,
)


class UpdateSelectMultiDefinitionParamsFieldConfiguration(UncheckedBaseModel):
    enable_add_new: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Allow or disallow adding in new option(s) from the grid/list view
    """

    options: typing.Optional[typing.List[UpdateSelectMultiDefinitionParamsFieldConfigurationOptionsItem]] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import httpx
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .environment import FrameioEnvironment

if typing.TYPE_CHECKING:
    from .account_permissions.client import AccountPermissionsClient, AsyncAccountPermissionsClient
    from .accounts.client import AccountsClient, AsyncAccountsClient
    from .comments.client import AsyncCommentsClient, CommentsClient
    from .files.client import AsyncFilesClient, FilesClient
    from .folders.client import AsyncFoldersClient, FoldersClient
    from .metadata.client import AsyncMetadataClient, MetadataClient
    from .metadata_fields.client import AsyncMetadataFieldsClient, MetadataFieldsClient
    from .project_permissions.client import AsyncProjectPermissionsClient, ProjectPermissionsClient
    from .projects.client import AsyncProjectsClient, ProjectsClient
    from .shares.client import AsyncSharesClient, SharesClient
    from .users.client import AsyncUsersClient, UsersClient
    from .version_stacks.client import AsyncVersionStacksClient, VersionStacksClient
    from .webhooks.client import AsyncWebhooksClient, WebhooksClient
    from .workspace_permissions.client import AsyncWorkspacePermissionsClient, WorkspacePermissionsClient
    from .workspaces.client import AsyncWorkspacesClient, WorkspacesClient


class Frameio:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : FrameioEnvironment
        The environment to use for requests from the client. from .environment import FrameioEnvironment



        Defaults to FrameioEnvironment.DEFAULT



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from frameio import Frameio

    client = Frameio(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: FrameioEnvironment = FrameioEnvironment.DEFAULT,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._metadata_fields: typing.Optional[MetadataFieldsClient] = None
        self._project_permissions: typing.Optional[ProjectPermissionsClient] = None
        self._folders: typing.Optional[FoldersClient] = None
        self._version_stacks: typing.Optional[VersionStacksClient] = None
        self._account_permissions: typing.Optional[AccountPermissionsClient] = None
        self._accounts: typing.Optional[AccountsClient] = None
        self._comments: typing.Optional[CommentsClient] = None
        self._webhooks: typing.Optional[WebhooksClient] = None
        self._workspace_permissions: typing.Optional[WorkspacePermissionsClient] = None
        self._shares: typing.Optional[SharesClient] = None
        self._metadata: typing.Optional[MetadataClient] = None
        self._files: typing.Optional[FilesClient] = None
        self._users: typing.Optional[UsersClient] = None
        self._projects: typing.Optional[ProjectsClient] = None
        self._workspaces: typing.Optional[WorkspacesClient] = None

    @property
    def metadata_fields(self):
        if self._metadata_fields is None:
            from .metadata_fields.client import MetadataFieldsClient  # noqa: E402

            self._metadata_fields = MetadataFieldsClient(client_wrapper=self._client_wrapper)
        return self._metadata_fields

    @property
    def project_permissions(self):
        if self._project_permissions is None:
            from .project_permissions.client import ProjectPermissionsClient  # noqa: E402

            self._project_permissions = ProjectPermissionsClient(client_wrapper=self._client_wrapper)
        return self._project_permissions

    @property
    def folders(self):
        if self._folders is None:
            from .folders.client import FoldersClient  # noqa: E402

            self._folders = FoldersClient(client_wrapper=self._client_wrapper)
        return self._folders

    @property
    def version_stacks(self):
        if self._version_stacks is None:
            from .version_stacks.client import VersionStacksClient  # noqa: E402

            self._version_stacks = VersionStacksClient(client_wrapper=self._client_wrapper)
        return self._version_stacks

    @property
    def account_permissions(self):
        if self._account_permissions is None:
            from .account_permissions.client import AccountPermissionsClient  # noqa: E402

            self._account_permissions = AccountPermissionsClient(client_wrapper=self._client_wrapper)
        return self._account_permissions

    @property
    def accounts(self):
        if self._accounts is None:
            from .accounts.client import AccountsClient  # noqa: E402

            self._accounts = AccountsClient(client_wrapper=self._client_wrapper)
        return self._accounts

    @property
    def comments(self):
        if self._comments is None:
            from .comments.client import CommentsClient  # noqa: E402

            self._comments = CommentsClient(client_wrapper=self._client_wrapper)
        return self._comments

    @property
    def webhooks(self):
        if self._webhooks is None:
            from .webhooks.client import WebhooksClient  # noqa: E402

            self._webhooks = WebhooksClient(client_wrapper=self._client_wrapper)
        return self._webhooks

    @property
    def workspace_permissions(self):
        if self._workspace_permissions is None:
            from .workspace_permissions.client import WorkspacePermissionsClient  # noqa: E402

            self._workspace_permissions = WorkspacePermissionsClient(client_wrapper=self._client_wrapper)
        return self._workspace_permissions

    @property
    def shares(self):
        if self._shares is None:
            from .shares.client import SharesClient  # noqa: E402

            self._shares = SharesClient(client_wrapper=self._client_wrapper)
        return self._shares

    @property
    def metadata(self):
        if self._metadata is None:
            from .metadata.client import MetadataClient  # noqa: E402

            self._metadata = MetadataClient(client_wrapper=self._client_wrapper)
        return self._metadata

    @property
    def files(self):
        if self._files is None:
            from .files.client import FilesClient  # noqa: E402

            self._files = FilesClient(client_wrapper=self._client_wrapper)
        return self._files

    @property
    def users(self):
        if self._users is None:
            from .users.client import UsersClient  # noqa: E402

            self._users = UsersClient(client_wrapper=self._client_wrapper)
        return self._users

    @property
    def projects(self):
        if self._projects is None:
            from .projects.client import ProjectsClient  # noqa: E402

            self._projects = ProjectsClient(client_wrapper=self._client_wrapper)
        return self._projects

    @property
    def workspaces(self):
        if self._workspaces is None:
            from .workspaces.client import WorkspacesClient  # noqa: E402

            self._workspaces = WorkspacesClient(client_wrapper=self._client_wrapper)
        return self._workspaces


class AsyncFrameio:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : FrameioEnvironment
        The environment to use for requests from the client. from .environment import FrameioEnvironment



        Defaults to FrameioEnvironment.DEFAULT



    token : typing.Union[str, typing.Callable[[], str]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from frameio import AsyncFrameio

    client = AsyncFrameio(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: FrameioEnvironment = FrameioEnvironment.DEFAULT,
        token: typing.Union[str, typing.Callable[[], str]],
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._metadata_fields: typing.Optional[AsyncMetadataFieldsClient] = None
        self._project_permissions: typing.Optional[AsyncProjectPermissionsClient] = None
        self._folders: typing.Optional[AsyncFoldersClient] = None
        self._version_stacks: typing.Optional[AsyncVersionStacksClient] = None
        self._account_permissions: typing.Optional[AsyncAccountPermissionsClient] = None
        self._accounts: typing.Optional[AsyncAccountsClient] = None
        self._comments: typing.Optional[AsyncCommentsClient] = None
        self._webhooks: typing.Optional[AsyncWebhooksClient] = None
        self._workspace_permissions: typing.Optional[AsyncWorkspacePermissionsClient] = None
        self._shares: typing.Optional[AsyncSharesClient] = None
        self._metadata: typing.Optional[AsyncMetadataClient] = None
        self._files: typing.Optional[AsyncFilesClient] = None
        self._users: typing.Optional[AsyncUsersClient] = None
        self._projects: typing.Optional[AsyncProjectsClient] = None
        self._workspaces: typing.Optional[AsyncWorkspacesClient] = None

    @property
    def metadata_fields(self):
        if self._metadata_fields is None:
            from .metadata_fields.client import AsyncMetadataFieldsClient  # noqa: E402

            self._metadata_fields = AsyncMetadataFieldsClient(client_wrapper=self._client_wrapper)
        return self._metadata_fields

    @property
    def project_permissions(self):
        if self._project_permissions is None:
            from .project_permissions.client import AsyncProjectPermissionsClient  # noqa: E402

            self._project_permissions = AsyncProjectPermissionsClient(client_wrapper=self._client_wrapper)
        return self._project_permissions

    @property
    def folders(self):
        if self._folders is None:
            from .folders.client import AsyncFoldersClient  # noqa: E402

            self._folders = AsyncFoldersClient(client_wrapper=self._client_wrapper)
        return self._folders

    @property
    def version_stacks(self):
        if self._version_stacks is None:
            from .version_stacks.client import AsyncVersionStacksClient  # noqa: E402

            self._version_stacks = AsyncVersionStacksClient(client_wrapper=self._client_wrapper)
        return self._version_stacks

    @property
    def account_permissions(self):
        if self._account_permissions is None:
            from .account_permissions.client import AsyncAccountPermissionsClient  # noqa: E402

            self._account_permissions = AsyncAccountPermissionsClient(client_wrapper=self._client_wrapper)
        return self._account_permissions

    @property
    def accounts(self):
        if self._accounts is None:
            from .accounts.client import AsyncAccountsClient  # noqa: E402

            self._accounts = AsyncAccountsClient(client_wrapper=self._client_wrapper)
        return self._accounts

    @property
    def comments(self):
        if self._comments is None:
            from .comments.client import AsyncCommentsClient  # noqa: E402

            self._comments = AsyncCommentsClient(client_wrapper=self._client_wrapper)
        return self._comments

    @property
    def webhooks(self):
        if self._webhooks is None:
            from .webhooks.client import AsyncWebhooksClient  # noqa: E402

            self._webhooks = AsyncWebhooksClient(client_wrapper=self._client_wrapper)
        return self._webhooks

    @property
    def workspace_permissions(self):
        if self._workspace_permissions is None:
            from .workspace_permissions.client import AsyncWorkspacePermissionsClient  # noqa: E402

            self._workspace_permissions = AsyncWorkspacePermissionsClient(client_wrapper=self._client_wrapper)
        return self._workspace_permissions

    @property
    def shares(self):
        if self._shares is None:
            from .shares.client import AsyncSharesClient  # noqa: E402

            self._shares = AsyncSharesClient(client_wrapper=self._client_wrapper)
        return self._shares

    @property
    def metadata(self):
        if self._metadata is None:
            from .metadata.client import AsyncMetadataClient  # noqa: E402

            self._metadata = AsyncMetadataClient(client_wrapper=self._client_wrapper)
        return self._metadata

    @property
    def files(self):
        if self._files is None:
            from .files.client import AsyncFilesClient  # noqa: E402

            self._files = AsyncFilesClient(client_wrapper=self._client_wrapper)
        return self._files

    @property
    def users(self):
        if self._users is None:
            from .users.client import AsyncUsersClient  # noqa: E402

            self._users = AsyncUsersClient(client_wrapper=self._client_wrapper)
        return self._users

    @property
    def projects(self):
        if self._projects is None:
            from .projects.client import AsyncProjectsClient  # noqa: E402

            self._projects = AsyncProjectsClient(client_wrapper=self._client_wrapper)
        return self._projects

    @property
    def workspaces(self):
        if self._workspaces is None:
            from .workspaces.client import AsyncWorkspacesClient  # noqa: E402

            self._workspaces = AsyncWorkspacesClient(client_wrapper=self._client_wrapper)
        return self._workspaces


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: FrameioEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .toggle_definition_params_field_configuration import ToggleDefinitionParamsFieldConfiguration


class ToggleDefinitionParams(UncheckedBaseModel):
    field_configuration: typing.Optional[ToggleDefinitionParamsFieldConfiguration] = None
    name: str = pydantic.Field()
    """
    Field definition name
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.webhook_events import WebhookEvents


class WebhookUpdateParamsData(UncheckedBaseModel):
    active: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Webhook active status
    """

    events: typing.Optional[WebhookEvents] = None
    name: typing.Optional[str] = None
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    URL where `event` is sent
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

LongTextDefinitionFieldType = typing.Union[
    typing.Literal[
        "text", "long_text", "select", "select_multi", "rating", "number", "toggle", "user_single", "user_multi", "date"
    ],
    typing.Any,
]



# This file was auto-generated by Fern from our API Definition.

import typing

UpdateRatingDefinitionParamsFieldConfigurationStyle = typing.Union[
    typing.Literal["star", "heart", "thumbs_up"], typing.Any
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .json_error_response_errors_item_source import JsonErrorResponseErrorsItemSource


class JsonErrorResponseErrorsItem(UncheckedBaseModel):
    detail: str
    source: JsonErrorResponseErrorsItemSource
    title: str

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel


class FileCreateRemoteUploadParamsData(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    File name
    """

    source_url: str = pydantic.Field()
    """
    Source URL - Initiates a remote upload from the provided URL
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from .remove_reviewer_params_data_reviewers import RemoveReviewerParamsDataReviewers


class RemoveReviewerParamsData(UncheckedBaseModel):
    reviewers: RemoveReviewerParamsDataReviewers

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ..core.pagination import AsyncPager, SyncPager
from ..core.request_options import RequestOptions
from ..types.include_total_count import IncludeTotalCount
from ..types.project_response import ProjectResponse
from ..types.project_with_includes import ProjectWithIncludes
from ..types.project_with_includes_response import ProjectWithIncludesResponse
from ..types.projects_with_includes_response import ProjectsWithIncludesResponse
from ..types.request_after_opaque_cursor import RequestAfterOpaqueCursor
from ..types.request_page_size import RequestPageSize
from ..types.uuid_ import Uuid
from .raw_client import AsyncRawProjectsClient, RawProjectsClient
from .types.project_params_data import ProjectParamsData
from .types.project_update_params_data import ProjectUpdateParamsData

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class ProjectsClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawProjectsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawProjectsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawProjectsClient
        """
        return self._raw_client

    def show(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["owner"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectWithIncludesResponse:
        """
        Show project details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        include : typing.Optional[typing.Literal["owner"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectWithIncludesResponse
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.projects.show(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.show(account_id, project_id, include=include, request_options=request_options)
        return _response.data

    def delete(
        self, account_id: Uuid, project_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a project. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.projects.delete(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
        )
        """
        _response = self._raw_client.delete(account_id, project_id, request_options=request_options)
        return _response.data

    def update(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        data: ProjectUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectResponse:
        """
        Update project details. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        data : ProjectUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectResponse
            OK

        Examples
        --------
        from frameio import Frameio
        from frameio.projects import ProjectUpdateParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.projects.update(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=ProjectUpdateParamsData(
                name="Project Name",
                restricted=True,
                status="active",
            ),
        )
        """
        _response = self._raw_client.update(account_id, project_id, data=data, request_options=request_options)
        return _response.data

    def index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["owner"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SyncPager[ProjectWithIncludes, ProjectsWithIncludesResponse]:
        """
        List projects in a given workspace. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["owner"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SyncPager[ProjectWithIncludes, ProjectsWithIncludesResponse]
            OK

        Examples
        --------
        from frameio import Frameio

        client = Frameio(
            token="YOUR_TOKEN",
        )
        response = client.projects.index(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            after="<opaque_cursor>",
            page_size=10,
            include_total_count=False,
        )
        for item in response:
            yield item
        # alternatively, you can paginate page-by-page
        for page in response.iter_pages():
            yield page
        """
        return self._raw_client.index(
            account_id,
            workspace_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )

    def create(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: ProjectParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectResponse:
        """
        Create project in a given workspace. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : ProjectParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectResponse
            Created

        Examples
        --------
        from frameio import Frameio
        from frameio.projects import ProjectParamsData

        client = Frameio(
            token="YOUR_TOKEN",
        )
        client.projects.create(
            account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            data=ProjectParamsData(
                name="Project Name",
                restricted=True,
            ),
        )
        """
        _response = self._raw_client.create(account_id, workspace_id, data=data, request_options=request_options)
        return _response.data


class AsyncProjectsClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawProjectsClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawProjectsClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawProjectsClient
        """
        return self._raw_client

    async def show(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["owner"]] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectWithIncludesResponse:
        """
        Show project details. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        include : typing.Optional[typing.Literal["owner"]]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectWithIncludesResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.projects.show(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.show(
            account_id, project_id, include=include, request_options=request_options
        )
        return _response.data

    async def delete(
        self, account_id: Uuid, project_id: Uuid, *, request_options: typing.Optional[RequestOptions] = None
    ) -> None:
        """
        Delete a project. <br>Rate Limits: 60 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        None

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.projects.delete(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.delete(account_id, project_id, request_options=request_options)
        return _response.data

    async def update(
        self,
        account_id: Uuid,
        project_id: Uuid,
        *,
        data: ProjectUpdateParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectResponse:
        """
        Update project details. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        project_id : Uuid


        data : ProjectUpdateParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectResponse
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.projects import ProjectUpdateParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.projects.update(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                project_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=ProjectUpdateParamsData(
                    name="Project Name",
                    restricted=True,
                    status="active",
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(account_id, project_id, data=data, request_options=request_options)
        return _response.data

    async def index(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        include: typing.Optional[typing.Literal["owner"]] = None,
        after: typing.Optional[RequestAfterOpaqueCursor] = None,
        page_size: typing.Optional[RequestPageSize] = None,
        include_total_count: typing.Optional[IncludeTotalCount] = None,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> AsyncPager[ProjectWithIncludes, ProjectsWithIncludesResponse]:
        """
        List projects in a given workspace. <br>Rate Limits: 100 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        include : typing.Optional[typing.Literal["owner"]]


        after : typing.Optional[RequestAfterOpaqueCursor]
            Opaque Cursor query param for requests returning paginated results.
            <br/>
            NOTE: this value is auto-generated and included as part of links from a previous response. It is not intended to be human readable.

        page_size : typing.Optional[RequestPageSize]


        include_total_count : typing.Optional[IncludeTotalCount]


        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        AsyncPager[ProjectWithIncludes, ProjectsWithIncludesResponse]
            OK

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            response = await client.projects.index(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                after="<opaque_cursor>",
                page_size=10,
                include_total_count=False,
            )
            async for item in response:
                yield item

            # alternatively, you can paginate page-by-page
            async for page in response.iter_pages():
                yield page


        asyncio.run(main())
        """
        return await self._raw_client.index(
            account_id,
            workspace_id,
            include=include,
            after=after,
            page_size=page_size,
            include_total_count=include_total_count,
            request_options=request_options,
        )

    async def create(
        self,
        account_id: Uuid,
        workspace_id: Uuid,
        *,
        data: ProjectParamsData,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> ProjectResponse:
        """
        Create project in a given workspace. <br>Rate Limits: 10 calls per 1.00 minute(s) per account_user

        Parameters
        ----------
        account_id : Uuid


        workspace_id : Uuid


        data : ProjectParamsData

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        ProjectResponse
            Created

        Examples
        --------
        import asyncio

        from frameio import AsyncFrameio
        from frameio.projects import ProjectParamsData

        client = AsyncFrameio(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.projects.create(
                account_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                workspace_id="b2702c44-c6da-4bb6-8bbd-be6e547ccf1b",
                data=ProjectParamsData(
                    name="Project Name",
                    restricted=True,
                ),
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.create(account_id, workspace_id, data=data, request_options=request_options)
        return _response.data



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import datetime as dt
import typing

import pydantic
from ...core.unchecked_base_model import UncheckedBaseModel
from ...types.asset_share_params_access import AssetShareParamsAccess


class CreateShareParamsData_Asset(UncheckedBaseModel):
    type: typing.Literal["asset"] = "asset"
    access: AssetShareParamsAccess
    asset_ids: typing.Optional[typing.List[str]] = None
    description: typing.Optional[str] = None
    downloading_enabled: typing.Optional[bool] = None
    expiration: typing.Optional[dt.datetime] = None
    name: str
    passphrase: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)


CreateShareParamsData = CreateShareParamsData_Asset



# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .asset_common_type import AssetCommonType
from .file_status import FileStatus


class File(UncheckedBaseModel):
    id: typing.Optional[str] = pydantic.Field(default=None)
    """
    File ID
    """

    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    File Name
    """

    file_size: int = pydantic.Field()
    """
    File size in bytes
    """

    media_type: str = pydantic.Field()
    """
    File media type
    """

    status: FileStatus
    created_at: dt.datetime = pydantic.Field()
    """
    Creation timestamp
    """

    parent_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Parent Folder or Version Stack ID
    """

    project_id: str = pydantic.Field()
    """
    Project ID
    """

    type: AssetCommonType
    updated_at: dt.datetime = pydantic.Field()
    """
    Update timestamp
    """

    view_url: str = pydantic.Field()
    """
    URL to view the asset in the Frame.io web application
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .media_link_common import MediaLinkCommon
from .original_media_link import OriginalMediaLink
from .rendition_media_link import RenditionMediaLink


class MediaLinksCollection(UncheckedBaseModel):
    efficient: typing.Optional[MediaLinkCommon] = None
    high_quality: typing.Optional[MediaLinkCommon] = None
    original: typing.Optional[OriginalMediaLink] = None
    thumbnail: typing.Optional[RenditionMediaLink] = None
    thumbnail_high_quality: typing.Optional[RenditionMediaLink] = None
    video_h_264_180: typing_extensions.Annotated[
        typing.Optional[RenditionMediaLink],
        FieldMetadata(alias="video_h264_180"),
        pydantic.Field(alias="video_h264_180", default=None),
    ]

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class UploadUrl(UncheckedBaseModel):
    size: int = pydantic.Field()
    """
    Upload chunk size
    """

    url: str = pydantic.Field()
    """
    S3 presigned URL. Client should make a PUT request to this URL that includes the "x-amz-acl: private" header along with the file or file chunk data.
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel
from .too_many_requests_errors_item_source import TooManyRequestsErrorsItemSource


class TooManyRequestsErrorsItem(UncheckedBaseModel):
    detail: str
    source: typing.Optional[TooManyRequestsErrorsItemSource] = None
    title: typing.Optional[str] = None

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
